@@ -15,7 +15,7 @@
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: nsupdate.c,v 1.75.2.1 2001/01/09 22:32:54 bwelling Exp $ */
+/* $Id: nsupdate.c,v 1.75.2.6 2001/05/02 22:27:08 gson Exp $ */
 
 #include <config.h>
 
@@ -26,10 +26,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#if (!(defined(HAVE_ADDRINFO) && defined(HAVE_GETADDRINFO)))
-extern int h_errno;
-#endif
-
 #include <isc/app.h>
 #include <isc/base64.h>
 #include <isc/buffer.h>
@@ -69,6 +65,18 @@ extern int h_errno;
 #include <lwres/lwres.h>
 #include <lwres/net.h>
 
+#ifdef HAVE_ADDRINFO
+#ifdef HAVE_GETADDRINFO
+#ifdef HAVE_GAISTRERROR
+#define USE_GETADDRINFO
+#endif
+#endif
+#endif
+
+#ifndef USE_GETADDRINFO
+extern int h_errno;
+#endif
+
 #define MAXCMD (4 * 1024)
 #define INITDATA (32 * 1024)
 #define MAXDATA (64 * 1024)
@@ -355,6 +363,50 @@ shutdown_program(isc_task_t *task, isc_event_t *event) {
 	isc_event_free(&event);
 	isc_task_detach(&global_task);
 	shuttingdown = ISC_TRUE;
+
+	if (userserver != NULL)
+		isc_mem_put(mctx, userserver, sizeof(isc_sockaddr_t));
+
+	if (localaddr != NULL)
+		isc_mem_put(mctx, localaddr, sizeof(isc_sockaddr_t));
+
+	if (key != NULL) {
+		debug("Freeing key");
+		dns_tsigkey_detach(&key);
+	}
+
+	if (updatemsg != NULL)
+		dns_message_destroy(&updatemsg);
+
+	if (is_dst_up) {
+		debug("Destroy DST lib");
+		dst_lib_destroy();
+		is_dst_up = ISC_FALSE;
+	}
+
+	if (entp != NULL) {
+		debug("Detach from entropy");
+		isc_entropy_detach(&entp);
+	}
+
+	lwres_conf_clear(lwctx);
+	lwres_context_destroy(&lwctx);
+
+	isc_mem_put(mctx, servers, ns_total * sizeof(isc_sockaddr_t));
+
+	ddebug("Shutting down request manager");
+	dns_requestmgr_shutdown(requestmgr);
+	dns_requestmgr_detach(&requestmgr);
+
+	ddebug("Freeing the dispatchers");
+	if (have_ipv4)
+		dns_dispatch_detach(&dispatchv4);
+	if (have_ipv6)
+		dns_dispatch_detach(&dispatchv6);
+
+	ddebug("Shutting down dispatch manager");
+	dns_dispatchmgr_destroy(&dispatchmgr);
+
 }
 
 static void
@@ -414,7 +466,10 @@ setup_system(void) {
 		}
 	}
 
-	result = dns_dispatchmgr_create(mctx, NULL, &dispatchmgr);
+	result = isc_entropy_create(mctx, &entp);
+	check_result(result, "isc_entropy_create");
+
+	result = dns_dispatchmgr_create(mctx, entp, &dispatchmgr);
 	check_result(result, "dns_dispatchmgr_create");
 
 	result = isc_socketmgr_create(mctx, &socketmgr);
@@ -432,9 +487,6 @@ setup_system(void) {
 	result = isc_task_onshutdown(global_task, shutdown_program, NULL);
 	check_result(result, "isc_task_onshutdown");
 
-	result = isc_entropy_create(mctx, &entp);
-	check_result(result, "isc_entropy_create");
-
 	result = dst_lib_init(mctx, entp, 0);
 	check_result(result, "dst_lib_init");
 	is_dst_up = ISC_TRUE;
@@ -493,7 +545,7 @@ static void
 get_address(char *host, in_port_t port, isc_sockaddr_t *sockaddr) {
 	struct in_addr in4;
 	struct in6_addr in6;
-#if defined(HAVE_ADDRINFO) && defined(HAVE_GETADDRINFO)
+#ifdef USE_GETADDRINFO
 	struct addrinfo *res = NULL;
 	int result;
 #else
@@ -506,7 +558,7 @@ get_address(char *host, in_port_t port, isc_sockaddr_t *sockaddr) {
 	else if (inet_pton(AF_INET, host, &in4) == 1)
 		isc_sockaddr_fromin(sockaddr, &in4, port);
 	else {
-#if defined(HAVE_ADDRINFO) && defined(HAVE_GETADDRINFO)
+#ifdef USE_GETADDRINFO
 		result = getaddrinfo(host, NULL, NULL, &res);
 		if (result != 0) {
 			fatal("Couldn't find server '%s': %s",
@@ -1138,6 +1190,8 @@ get_next_command(void) {
 		return (STATUS_QUIT);
 	if (*word == 0)
 		return (STATUS_SEND);
+	if (word[0] == ';')
+		return (STATUS_MORE);
 	if (strcasecmp(word, "quit") == 0)
 		return (STATUS_QUIT);
 	if (strcasecmp(word, "prereq") == 0)
@@ -1185,12 +1239,22 @@ update_completed(isc_task_t *task, isc_event_t *event) {
 	dns_requestevent_t *reqev = NULL;
 	isc_result_t result;
 	dns_message_t *rcvmsg = NULL;
+	dns_request_t *request;
 
 	UNUSED(task);
 
 	ddebug("update_completed()");
+
 	REQUIRE(event->ev_type == DNS_EVENT_REQUESTDONE);
 	reqev = (dns_requestevent_t *)event;
+	request = reqev->request;
+
+	if (shuttingdown) {
+		dns_request_destroy(&request);
+		isc_event_free(&event);
+		return;
+	}
+
 	if (reqev->result != ISC_R_SUCCESS) {
 		fprintf(stderr, "; Communication with server failed: %s\n",
 			isc_result_totext(reqev->result));
@@ -1200,7 +1264,7 @@ update_completed(isc_task_t *task, isc_event_t *event) {
 
 	result = dns_message_create(mctx, DNS_MESSAGE_INTENTPARSE, &rcvmsg);
 	check_result(result, "dns_message_create");
-	result = dns_request_getresponse(reqev->request, rcvmsg,
+	result = dns_request_getresponse(request, rcvmsg,
 					 DNS_MESSAGEPARSE_PRESERVEORDER);
 	check_result(result, "dns_request_getresponse");
 	if (rcvmsg->rcode != dns_rcode_noerror)
@@ -1231,7 +1295,7 @@ update_completed(isc_task_t *task, isc_event_t *event) {
 	}
 	dns_message_destroy(&rcvmsg);
  done:
-	dns_request_destroy(&reqev->request);
+	dns_request_destroy(&request);
 	isc_event_free(&event);
 	done_update();
 }
@@ -1300,8 +1364,13 @@ recvsoa(isc_task_t *task, isc_event_t *event) {
 	soaquery = reqinfo->msg;
 	addr = reqinfo->addr;
 
-	isc_event_free(&event);
-	reqev = NULL;
+	if (shuttingdown) {
+		dns_request_destroy(&request);
+		dns_message_destroy(&soaquery);
+		isc_mem_put(mctx, reqinfo, sizeof(nsu_requestinfo_t));
+		isc_event_free(&event);
+		return;
+	}
 
 	if (eresult != ISC_R_SUCCESS) {
 		char addrbuf[ISC_SOCKADDR_FORMATSIZE];
@@ -1318,10 +1387,14 @@ recvsoa(isc_task_t *task, isc_event_t *event) {
 		dns_message_renderreset(soaquery);
 		sendrequest(localaddr, &servers[ns_inuse], soaquery, &request);
 		isc_mem_put(mctx, reqinfo, sizeof(nsu_requestinfo_t));
+		isc_event_free(&event);
 		return;
 	}
 	isc_mem_put(mctx, reqinfo, sizeof(nsu_requestinfo_t));
 
+	isc_event_free(&event);
+	reqev = NULL;
+
 	ddebug("About to create rcvmsg");
 	result = dns_message_create(mctx, DNS_MESSAGE_INTENTPARSE, &rcvmsg);
 	check_result(result, "dns_message_create");
@@ -1553,49 +1626,6 @@ static void
 cleanup(void) {
 	ddebug("cleanup()");
 
-	if (userserver != NULL)
-		isc_mem_put(mctx, userserver, sizeof(isc_sockaddr_t));
-
-	if (localaddr != NULL)
-		isc_mem_put(mctx, localaddr, sizeof(isc_sockaddr_t));
-
-	if (key != NULL) {
-		debug("Freeing key");
-		dns_tsigkey_detach(&key);
-	}
-
-	if (updatemsg != NULL)
-		dns_message_destroy(&updatemsg);
-
-	if (is_dst_up) {
-		debug("Destroy DST lib");
-		dst_lib_destroy();
-		is_dst_up = ISC_FALSE;
-	}
-
-	if (entp != NULL) {
-		debug("Detach from entropy");
-		isc_entropy_detach(&entp);
-	}
-
-	lwres_conf_clear(lwctx);
-	lwres_context_destroy(&lwctx);
-
-	isc_mem_put(mctx, servers, ns_total * sizeof(isc_sockaddr_t));
-
-	ddebug("Shutting down request manager");
-	dns_requestmgr_shutdown(requestmgr);
-	dns_requestmgr_detach(&requestmgr);
-
-	ddebug("Freeing the dispatchers");
-	if (have_ipv4)
-		dns_dispatch_detach(&dispatchv4);
-	if (have_ipv6)
-		dns_dispatch_detach(&dispatchv6);
-
-	ddebug("Shutting down dispatch manager");
-	dns_dispatchmgr_destroy(&dispatchmgr);
-
 	ddebug("Shutting down task manager");
 	isc_taskmgr_destroy(&taskmgr);
 
@@ -1620,6 +1650,9 @@ getinput(isc_task_t *task, isc_event_t *event) {
 
 	UNUSED(task);
 
+	if (shuttingdown)
+		return;
+
 	if (global_event == NULL)
 		global_event = event;
 
