@@ -1,21 +1,21 @@
 /*
- * Copyright (C) 1999, 2000  Internet Software Consortium.
- * 
+ * Copyright (C) 1999-2001  Internet Software Consortium.
+ *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
- * 
- * THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM DISCLAIMS
- * ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET SOFTWARE
- * CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL
- * DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
- * PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
- * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
- * SOFTWARE.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM
+ * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
+ * INTERNET SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
+ * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: log.h,v 1.25.2.1 2000/08/22 01:45:26 bwelling Exp $ */
+/* $Id: log.h,v 1.35.2.1 2001/01/09 22:50:04 bwelling Exp $ */
 
 #ifndef ISC_LOG_H
 #define ISC_LOG_H 1
@@ -28,8 +28,6 @@
 #include <isc/lang.h>
 #include <isc/types.h>
 
-ISC_LANG_BEGINDECLS
-
 /*
  * Severity levels, patterned after Unix's syslog levels.
  *
@@ -109,6 +107,7 @@ typedef struct isc_logfile {
 	 * to a size large enough for the largest possible file on a system.
 	 */
 	isc_offset_t maximum_size;
+	isc_boolean_t maximum_reached; /* Private. */
 } isc_logfile_t;
 
 /*
@@ -140,6 +139,8 @@ extern isc_logmodule_t isc_modules[];
 
 #define ISC_LOGMODULE_SOCKET (&isc_modules[0])
 
+ISC_LANG_BEGINDECLS
+
 isc_result_t
 isc_log_create(isc_mem_t *mctx, isc_log_t **lctxp, isc_logconfig_t **lcfgp);
 /*
@@ -152,12 +153,12 @@ isc_log_create(isc_mem_t *mctx, isc_log_t **lctxp, isc_logconfig_t **lcfgp);
  * Requires:
  *	mctx is a valid memory context.
  *	lctxp is not null and *lctxp is null.
- *	lctfg is not null and *lcfgp is null.
+ *	lcfgp is null or lcfgp is not null and *lcfgp is null.
  *
  * Ensures:
  *	*lctxp will point to a valid logging context if all of the necessary
  *	memory was allocated, or NULL otherwise.
- *	*lcfgp will point to a valid logging configuration if all of the 
+ *	*lcfgp will point to a valid logging configuration if all of the
  *	necessary memory was allocated, or NULL otherwise.
  *	On failure, no additional memory is allocated.
  *
@@ -470,7 +471,7 @@ isc_log_usechannel(isc_logconfig_t *lcfg, const char *name,
  *
  * Requires:
  *	lcfg is a valid logging configuration.
- *	
+ *
  *	category is NULL or has an id that is in the range of known ids.
  *
  *	module is NULL or has an id that is in the range of known ids.
@@ -499,12 +500,16 @@ isc_log_usechannel(isc_logconfig_t *lcfg, const char *name,
 
 void
 isc_log_write(isc_log_t *lctx, isc_logcategory_t *category,
-	      isc_logmodule_t *module, int level, const char *format, ...)
+	      isc_logmodule_t *module, int level,
+	      const char *format, ...)
 ISC_FORMAT_PRINTF(5, 6);
 /*
  * Write a message to the log channels.
  *
  * Notes:
+ *	Log message containing natural language text should be logged with
+ *	isc_log_iwrite() to allow for localization.
+ *
  *	lctx can be NULL; this is allowed so that programs which use
  *	libraries that use the ISC logging system are not required to
  *	also use it.
@@ -536,8 +541,8 @@ ISC_FORMAT_PRINTF(5, 6);
 
 void
 isc_log_vwrite(isc_log_t *lctx, isc_logcategory_t *category,
-	       isc_logmodule_t *module, int level, const char *format,
-	       va_list args)
+	       isc_logmodule_t *module, int level,
+	       const char *format, va_list args)
 ISC_FORMAT_PRINTF(5, 0);
 /*
  * Write a message to the log channels.
@@ -574,7 +579,7 @@ ISC_FORMAT_PRINTF(5, 0);
 
 void
 isc_log_write1(isc_log_t *lctx, isc_logcategory_t *category,
-	      isc_logmodule_t *module, int level, const char *format, ...)
+	       isc_logmodule_t *module, int level, const char *format, ...)
 ISC_FORMAT_PRINTF(5, 6);
 /*
  * Write a message to the log channels, pruning duplicates that occur within
@@ -584,8 +589,8 @@ ISC_FORMAT_PRINTF(5, 6);
 
 void
 isc_log_vwrite1(isc_log_t *lctx, isc_logcategory_t *category,
-	       isc_logmodule_t *module, int level, const char *format,
-	       va_list args)
+		isc_logmodule_t *module, int level, const char *format,
+		va_list args)
 ISC_FORMAT_PRINTF(5, 0);
 /*
  * Write a message to the log channels, pruning duplicates that occur within
@@ -593,6 +598,46 @@ ISC_FORMAT_PRINTF(5, 0);
  * This function is otherwise identical to isc_log_vwrite().
  */
 
+void
+isc_log_iwrite(isc_log_t *lctx, isc_logcategory_t *category,
+	      isc_logmodule_t *module, int level,
+	      isc_msgcat_t *msgcat, int msgset, int message,
+	      const char *format, ...)
+ISC_FORMAT_PRINTF(8, 9);
+
+void
+isc_log_ivwrite(isc_log_t *lctx, isc_logcategory_t *category,
+		isc_logmodule_t *module, int level,
+		isc_msgcat_t *msgcat, int msgset, int message,
+		const char *format, va_list args)
+ISC_FORMAT_PRINTF(8, 0);
+
+void
+isc_log_iwrite1(isc_log_t *lctx, isc_logcategory_t *category,
+		isc_logmodule_t *module, int level,
+		isc_msgcat_t *msgcat, int msgset, int message,
+		const char *format, ...)
+ISC_FORMAT_PRINTF(8, 9);
+
+void
+isc_log_ivwrite1(isc_log_t *lctx, isc_logcategory_t *category,
+		 isc_logmodule_t *module, int level,
+		 isc_msgcat_t *msgcat, int msgset, int message,
+		 const char *format, va_list args)
+ISC_FORMAT_PRINTF(8, 0);
+/*
+ * These are four internationalized versions of the the isc_log_[v]write[1]
+ * functions.  The only difference is that they take arguments for a message
+ * catalog, message set, and message number, all immediately preceding the
+ * format argument.  The format argument becomes the default text, a la
+ * isc_msgcat_get.  If the message catalog is NULL, no lookup is attempted
+ * for a message -- which makes the message set and message number irrelevant,
+ * and the non-internationalized call should have probably been used instead.
+ *
+ * Yes, that means there are now *eight* interfaces to logging a message.
+ * Sheesh.   Make the madness stop!
+ */
+
 void
 isc_log_setdebuglevel(isc_log_t *lctx, unsigned int level);
 /*
@@ -622,7 +667,7 @@ isc_log_getdebuglevel(isc_log_t *lctx);
  *
  * Requires:
  *	lctx is a valid logging context.
- *	
+ *
  * Ensures:
  *	The current logging debugging level is returned.
  */
@@ -784,7 +829,7 @@ isc_logcategory_t *
 isc_log_categorybyname(isc_log_t *lctx, const char *name);
 /*
  * Find a category by its name.
- * 
+ *
  * Notes:
  *	The string name of a category is not required to be unique.
  *
@@ -802,7 +847,7 @@ isc_logmodule_t *
 isc_log_modulebyname(isc_log_t *lctx, const char *name);
 /*
  * Find a module by its name.
- * 
+ *
  * Notes:
  *	The string name of a module is not required to be unique.
  *
@@ -823,7 +868,6 @@ isc_log_setcontext(isc_log_t *lctx);
  *
  * Requires:
  *	lctx be a valid context.
- *	This function must not have been previously called.
  */
 
 ISC_LANG_ENDDECLS
